; Personal settings for Emacs.

; Personal X resources for Emacs can be set in ~/.Xdefaults.
; Look also at the global configuration in /etc/emacs/.

; Emacs has a customization menu, changes done there are written 
; into this file.
; For example, to turn off the autostart of Flyspell, customize
; Data->"Text Mode Hook" item.

;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
; Minimal settings for users of Emacs who work in 
; Russian (CP1251) environment.
; 
; ALT Linux Team, February 2002.

(XEmacs
    (set-language-environment "Cyrillic-ISO")
    (set-input-method "cyrillic-jcuken")
)
(GNUEmacs
    (set-language-environment "Cyrillic-CP1251")

; The following lines make the corresponding 
; parameters independent of the current language-environment:
; if you change language-environment, they won't be changed;
; but if you comment out some of them, they will follow the
; language-environment parameter:
    (set-terminal-coding-system 'cp1251)
    (set-keyboard-coding-system 'cp1251)
    ; This could help for transferring data from bad old apps
    ;(set-selection-coding-system 'cp1251)

)    

; End of the language environment settings.
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
(custom-set-variables
  ;; custom-set-variables was added by Custom.
  ;; If you edit it by hand, you could mess it up, so be careful.
  ;; Your init file should contain only one such instance.
  ;; If there is more than one, they won't work right.
 '(auto-compression-mode t nil (jka-compr))
 '(case-fold-search t)
 '(column-number-mode t)
 '(current-language-environment "Cyrillic-CP1251")
 '(default-input-method "rfc1345")
 '(desktop-missing-file-warning t)
 '(desktop-save-mode t)
 '(emacs-wiki-charset-default "cp1251")
 '(emacs-wiki-coding-default (quote cp1251))
 '(emacs-wiki-publish-url-coding-system (quote cp1251))
 '(global-font-lock-mode t nil (font-lock))
 '(inferior-lisp-program "sbcl")
 '(planner-trunk-rule-list (quote (("." nil ("Celestia" "SmallReality" "eBudget" "pFormatter" "Clara" "AroksWeb" "AroksMantis" "GTKTalog" "Prawda" "TimeMantis" "MyProjects" "Finance" "TimePlan" "Documents " "Shopping" "Hobby" "Family" "Personal" "Linux" "Home" "Documents" "Politics")))))
 '(save-place t nil (saveplace))
 '(show-paren-mode t nil (paren))
 '(tab-width 3)
 '(text-mode-hook (quote (turn-on-auto-fill text-mode-hook-identify)))
 '(transient-mark-mode t)
 '(uniquify-buffer-name-style (quote forward) nil (uniquify))
 '(w3-default-homepage "http://localhost"))
(custom-set-faces
  ;; custom-set-faces was added by Custom.
  ;; If you edit it by hand, you could mess it up, so be careful.
  ;; Your init file should contain only one such instance.
  ;; If there is more than one, they won't work right.
 '(default ((t (:stipple nil :background "honeydew" :foreground "black" :inverse-video nil :box nil :strike-through nil :overline nil :underline nil :slant normal :weight normal :height 140 :width normal :family "adobe-courier"))))
 '(emacs-wiki-header-1 ((t (:inherit variable-pitch :weight bold :height 180))))
 '(emacs-wiki-header-2 ((t (:inherit variable-pitch :weight bold :height 140 :family "*"))))
 '(emacs-wiki-header-3 ((t (:inherit variable-pitch :weight bold :height 120)))))

(setq tab-width 3)
(setq visible-bell t)

(require 'show-wspace) ; Load this library.
(add-hook 'font-lock-mode-hook 'highlight-tabs)

(autoload 'python-mode2.4 "python-mode" "Major mode for Python programs" t)

(require 'javascript-mode)
(add-to-list 'auto-mode-alist '("\\.js\\'" . javascript-mode))

(autoload 'css-mode "css-mode")
(setq auto-mode-alist       
		(cons '("\\.css\\'" . css-mode) auto-mode-alist))
(setq cssm-indent-function #'cssm-c-style-indenter)
(setq cssm-indent-level '2)

(require 'php-mode)
(add-hook 'php-mode-user-hook 'turn-on-font-lock)
(add-hook 'php-mode-user-hook
			 '(lambda () (define-abbrev php-mode-abbrev-table "ex" "extends")))

(require 'mmm-mode)
(setq mmm-global-mode 'maybe)

(mmm-add-group
 'fancy-html
 '(
	(html-php-tagged
	 :submode php-mode
	 :face mmm-code-submode-face
	 :front "<[?]php"
	 :back "[?]>")
	(html-js-tagged
	 :submode javascript-mode
	 :face mmm-code-submode-face
	 :front "<script language=\"JavaScript\""
	 :back "</script>")

	(html-css-attribute
	 :submode css-mode
	 :face mmm-declaration-submode-face
	 :front "style=\""
	 :back "\"")))

(add-to-list 'auto-mode-alist '("\\.inc\\'" . html-mode))
(add-to-list 'auto-mode-alist '("\\.phtml\\'" . html-mode))
(add-to-list 'auto-mode-alist '("\\.php[34]?\\'" . html-mode))
(add-to-list 'auto-mode-alist '("\\.[sj]?html?\\'" . html-mode))
(add-to-list 'auto-mode-alist '("\\.jsp\\'" . html-mode))

(add-to-list 'mmm-mode-ext-classes-alist '(html-mode nil html-js))
(add-to-list 'mmm-mode-ext-classes-alist '(html-mode nil embedded-css))
(add-to-list 'mmm-mode-ext-classes-alist '(html-mode nil fancy-html))

(defun go-bind-markup-menu-to-mouse3 ()
  (define-key sgml-mode-map [(down-mouse-3)] 'sgml-tags-menu))

(add-hook 'sgml-mode-hook 'go-bind-markup-menu-to-mouse3)

(add-to-list 'auto-mode-alist '("\\.e\\'" . eiffel-mode))
(autoload 'eiffel-mode "eiffel-mode" "Major mode for Eiffel programs" t)

(setq hol98-executable "/home/eugine/src/hol/bin/hol.unquote")
(load "hol98-mode")

(setq load-path (append load-path '("/usr/share/emacs/site-lisp/subversion")))
(autoload 'svn-status "psvn" "Emacs interface to Subversion." t)
(add-to-list 'vc-handled-backends 'SVN)

(setq planner-project "WikiPlanner")
(setq muse-project-alist
     '(("WikiPlanner"
        ("~/Plans"           ;; where your Planner pages are located
         :default "TaskPool" ;; use value of `planner-default-page'
         :major-mode planner-mode
         :visit-link planner-visit-link)

        ;; This next part is for specifying where Planner pages
        ;; should be published and what Muse publishing style to
        ;; use.  In this example, we will use the XHTML publishing
        ;; style.

        (:base "planner-xhtml"
               ;; value of `planner-publishing-directory'
               :path "~/public_html/Plans"))))
(require 'planner-cyclic)
(setq planner-cyclic-diary-nag nil)
(require 'planner-trunk)
(require 'planner-timeclock)
(require 'planner-timeclock-summary)
(require 'planner-timeclock-summary-proj)

(require 'remember-planner)
(setq remember-handler-functions '(remember-planner-append))
(setq remember-annotation-functions planner-annotation-functions)
(require 'planner-diary)
(add-hook 'diary-display-hook 'fancy-diary-display)
(setq planner-day-page-template
		"* Tasks\n\n\n* Diary\n\n<lisp>(planner-diary-entries-here)</lisp>\n\n* Notes")
(setq planner-diary-use-diary t)
(planner-diary-insinuate)

(require 'planner-appt)
(planner-appt-use-tasks-and-schedule)
(planner-appt-insinuate)

(desktop-load-default)
(desktop-read)
(plan)